@@ -18,13 +18,13 @@
 """A CLI tool and library for interacting with Amun."""
 
 __name__ = 'amun'
-__version__ = "0.3.2"
+__version__ = "0.5.0"
 __author__ = 'Fridolin Pokorny <fridolin.pokorny@gmail.com>'
 
 from .lib import inspect
 from .lib import instantiate_inspection_api
 from .lib import get_inspection_build_log
-from .lib import get_inspection_job_log
+from .lib import get_inspection_job_logs
 from .lib import get_inspection_specification
 from .lib import get_inspection_status
 from .lib import is_inspection_finished
